;************************************************************************
;*****  PWM utility library for the 8520 uP
;************************************************************************
#include    p18f8520.inc

;Routines
    GLOBAL  tGenerate_Pwms,pwmData,delay1,delay2,MaxStepVar

;Variables

#define MASK_BIT                LATG,0  ;CCP3
#define TRIG                    LATG,3  ;CCP4
#define TRIG2                   LATG,4  ;CCP5

#define NO_EDGE_PROTECTOIN      1
 
#define PRE_PROTECT_VALUE       1
#define PROTECT_BIT             LookAhead,PRE_PROTECT_VALUE-1
#define MAX_STEP_SIZE           .230

#define ENABLE_PROTECTION		UserVar,0

 ifdef _RADIO_SHACK
#define	sPWM01	                PORTE,0     ;PWM Signal Pins
#define	sPWM02	                PORTE,1
#define	sPWM03	                PORTE,2
#define	sPWM04	                PORTE,3
#define	sPWM05	                PORTE,4
#define	sPWM06	                PORTE,5
#define	sPWM07	                PORTE,6
#define	sPWM08	                PORTE,7
 else                                       ;EDU User PWM pins
#define	sPWM01	                LATE,7      ;CCP2 - PWM Signal Pins
#define	sPWM02	                SPARE,1
#define	sPWM03	                SPARE,2
#define	sPWM04	                SPARE,3
#define	sPWM05	                SPARE,4
#define	sPWM06	                SPARE,5
#define	sPWM07	                SPARE,6
#define	sPWM08	                SPARE,7
 endif

;*****************************************************************************
UTIL_ACS                        UDATA_ACS
LookAhead						RES		1
Cnt                             RES     1
Cnt1                            RES     1
pwmData										;Takes on same address as gPWM_DATA1
gPWM_DATA1                      RES     1
gPWM_DATA2                      RES     1
gPWM_DATA3                      RES     1
gPWM_DATA4                      RES     1
gPWM_DATA5                      RES     1
gPWM_DATA6                      RES     1
gPWM_DATA7                      RES     1
gPWM_DATA8                      RES     1
FSR0H_TEMP                      RES     1
FSR0L_TEMP                      RES     1
SPARE                           RES     1
delay1                          RES     1
delay2                          RES     1
MaxStepVar                      RES     1
UserVar							RES		1
MaxSteps                        RES     1

PWM_LIB    CODE
;*****************************************************************************

tGenerate_Pwms			        ;(unsigned char *pwmdata)
;    movlw   MAX_STEP_SIZE
    movff   MaxStepVar,MaxSteps
    movlw   B'11000000'         ;8 bit, Timer On, Div 2
    movwf   T0CON
    clrf    Cnt
    clrf    LookAhead
	bcf		LATG,4
PulseLoop
    bcf     INTCON,TMR0IF
    movf    delay2,w
    movwf   TMR0L
    movlw   B'00010000'
    xorwf   LATG,f
TestPwm1
    bsf     TRIG
 	dcfsnz	gPWM_DATA1,f        ;Complete 1st PWM delay cycle
	bcf	    sPWM01
	dcfsnz	gPWM_DATA2,f        ;Complete 2nd PWM delay cycle
	bcf	    sPWM02
	dcfsnz	gPWM_DATA3,f        ;Complete 3rd PWM delay cycle
	bcf	    sPWM03
	dcfsnz	gPWM_DATA4,f        ;Complete 4th PWM delay cycle
	bcf	    sPWM04
	dcfsnz	gPWM_DATA5,f        ;Complete 5th PWM delay cycle
	bcf	    sPWM05
	dcfsnz	gPWM_DATA6,f        ;Complete 6th PWM delay cycle
	bcf	    sPWM06
	dcfsnz	gPWM_DATA7,f        ;Complete 7th PWM delay cycle
	bcf	    sPWM07
	dcfsnz	gPWM_DATA8,f        ;Complete 8th PWM delay cycle
	bcf	    sPWM08

; ifdef NO_EDGE_PROTECTOIN
	btfss	ENABLE_PROTECTION
    bra     Wait4Next           ;**** TEMP *****
; endif

    movf    LookAhead,w
    btfsc   STATUS,Z
    bra     CheckPWM1           ;then, check PWM1
	decfsz	LookAhead,f         ;Complete 8th PWM delay cycle
	bra		End_Checks

    bsf     INTCON,GIEH         ;Enable high ints
    bsf     INTCON,GIEL         ;Enable low ints
    bcf     MASK_BIT

CheckPWM1                       ;*** Protect only channels 1-4 (5-6 are buttons) ***
 	movf	gPWM_DATA1,w        ;if gPWM_DATA1 == 2 then set LookAhead
    xorlw   PRE_PROTECT_VALUE                      
    btfss   STATUS,Z
    bra     CheckPWM2    
	bsf		PROTECT_BIT
	bra		End_Checks
CheckPWM2
 	movf	gPWM_DATA2,w        ;if gPWM_DATA1 == 2 then set LookAhead
    xorlw   PRE_PROTECT_VALUE                      
    btfss   STATUS,Z
    bra     CheckPWM3    
	bsf		PROTECT_BIT
	bra		End_Checks
CheckPWM3
 	movf	gPWM_DATA3,w        ;if gPWM_DATA1 == 2 then set LookAhead
    xorlw   PRE_PROTECT_VALUE                      
    btfss   STATUS,Z
    bra     CheckPWM4    
	bsf		PROTECT_BIT
	bra		End_Checks
CheckPWM4
 	movf	gPWM_DATA4,w        ;if gPWM_DATA1 == 2 then set LookAhead
    xorlw   PRE_PROTECT_VALUE                      
    btfss   STATUS,Z
    bra     End_Checks    
	bsf		PROTECT_BIT
End_Checks
	btfss   PROTECT_BIT
    bra     Wait4Next
    bcf     INTCON,GIEH         ;Disable high ints
    bcf     INTCON,GIEL         ;Disable low ints
    bsf     MASK_BIT
Wait4Next
    bcf     TRIG
    btfss   INTCON,TMR0IF
	bra		Wait4Next
	decfsz	MaxSteps,f          
	bra	    PulseLoop
	bcf	    sPWM01              ;Make sure all pins are clear
	bcf	    sPWM02
	bcf	    sPWM03
	bcf	    sPWM04
	bcf	    sPWM05
	bcf	    sPWM06
	bcf	    sPWM07
	bcf	    sPWM08
    bsf     INTCON,GIEH         ;Enable high ints
    bsf     INTCON,GIEL         ;Enable low ints
    bcf     MASK_BIT
	bcf		T0CON,TMR0ON		;Turn timer off
    return
 
    END


